@@ -30,7 +30,7 @@
 Leonardo <-
     function()
 {
-    access_token <- gcloud_access_token("leonardo")
+    access_token <- GCPtools::gcloud_access_token("leonardo")
     api_header <- c(
         Authorization = paste("Bearer", access_token),
         Referer = "https://leonardo.dsde-prod.broadinstitute.org"
