@@ -18,8 +18,10 @@
 #'
 #' @format NULL
 #'
+#' @importFrom GCPtools gcloud_access_token
+#'
 #' @examples
-#' library(AnVILGCP)
+#' library(GCPtools)
 #' if (gcloud_exists()) {
 #'     tags(Rawls())
 #'     tags(Rawls(), "billing")
@@ -29,9 +31,7 @@
 Rawls <-
     function()
 {
-    if (!requireNamespace("AnVILGCP", quietly = TRUE))
-        stop("Install 'AnVILGCP' to use 'Rawls()'", call. = FALSE)
-    access_token <- AnVILGCP::gcloud_access_token("rawls")
+    access_token <- GCPtools::gcloud_access_token("rawls")
     api_header <- c(Authorization = paste("Bearer", access_token))
     .Rawls(
         Service(
