@@ -17,8 +17,10 @@
 #'
 #' @format NULL
 #'
+#' @importFrom GCPtools gcloud_access_token
+#'
 #' @examples
-#' library(AnVILGCP)
+#' library(GCPtools)
 #' if (gcloud_exists())
 #'     TDR()
 #'
@@ -26,9 +28,7 @@
 TDR <-
     function()
 {
-    if (!requireNamespace("AnVILGCP", quietly = TRUE))
-        stop("Install 'AnVILGCP' to use 'TDR()'", call. = FALSE)
-    access_token <- AnVILGCP::gcloud_access_token("tdr")
+    access_token <- GCPtools::gcloud_access_token("tdr")
     api_header <- c(
         Authorization = paste("Bearer", access_token)
     )
