@@ -31,7 +31,7 @@
 Terra <-
     function()
 {
-    access_token <- gcloud_access_token("terra")
+    access_token <- GCPtools::gcloud_access_token("terra")
     api_header <- c(Authorization = paste("Bearer", access_token))
     .Terra(
         Service(
